# minecrypto
A W.I.P python module that allows you to mine crypto in your programs.
## Docs
These docs are W.I.P
### Duino-Coin
> minecrypto.duinocoin(username, UseLowerDiff)
This allows you to mine Duino-Coin

> minecrypto.duinocoinwithxxhash(username)
This allows you to mine Duino-Coin with XXHASH

## Upcoming features
+ Faucet's
+ More crypto's like bitcoin and dogecoin
+ API's
+ More cryptos
+ Anything else you want
